/*
 * Copyright (c) 2011-2013, ScalaFX Project
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the ScalaFX Project nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE SCALAFX PROJECT OR ITS CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package scalafx.scene.effect

import javafx.scene.{effect => jfxse}
import scalafx.Includes._
import scalafx.beans.property.IntegerProperty
import scalafx.delegate.DimensionDelegate
import scalafx.delegate.SFXDelegate

object BoxBlur {
  implicit def sfxBoxBlur2jfx(bb: BoxBlur) = bb.delegate
}

/** 
 * Wraps [[http://docs.oracle.com/javafx/2/api/javafx/scene/effect/BoxBlur.html]]
 */
class BoxBlur(override val delegate: jfxse.BoxBlur = new jfxse.BoxBlur)
  extends Effect(delegate)
  with DimensionDelegate[jfxse.BoxBlur]
  with InputDelegate[jfxse.BoxBlur]
  with SFXDelegate[jfxse.BoxBlur] {

  /**
   * Creates a new instance of BoxBlur with specified width, height and iterations.
   */
  def this(width: Double, height: Double, iterations: Int) = this(new jfxse.BoxBlur(width, height, iterations))

  /**
   * The number of times to iterate the blur effect to improve its "quality" or "smoothness".
   */
  def iterations: IntegerProperty = delegate.iterationsProperty
  def iterations_=(v: Int) {
    iterations() = v
  }

}